## Plotting routines for EFMA figures, requiring output from MATLAB scripts saved in .csv files

## ------------------------------------------------------------------------------------------ ##
## Figure 2 plotting routine
## ------------------------------------------------------------------------------------------ ##

import matplotlib.pyplot as plt
from matplotlib import colors

# Open .csv output file generated by MATLAB analysis
infile_total = open('total_O2X_hvX.csv','r') # Data for biomass-producing EFMs

# Create variable names
tot_x = []
tot_y = []
Z = []

# Build variable lists from data stored in .csv file
while True:
    line = infile_total.readline()
    if (line == ''):
        break
    values = line.split(',')
    if float(values[0]) <= 10 and float(values[1]) <= 200 and float(values[2]) <= 6:
        tot_x.append(float(values[1])) # Photon absorption per biomass values for each EFM
        tot_y.append(float(values[0])) # O2 evolved per biomass values for each EFM
        Z.append(float(values[2])) # PSII/I photon absorption ratio for each EFM
infile_total.close()

# Create graphic
fig = plt.figure()
ax = fig.add_subplot(1,1,1)
# Specify colormap
cmap = plt.cm.get_cmap('hot_r')
bounds = [0,0.6,1.2,1.8,2.4,3.0,3.6,4.2,4.8,5.4,6.0] # Specify divisions for colorscale
norm = colors.BoundaryNorm(bounds,cmap.N)
# Plot EFMs
sc = plt.scatter(tot_x,tot_y,c=Z,vmin=0,vmax=20,s=80,cmap=cmap,norm=norm)
# Specify plot parameters
ax.set_xlabel('Photon Absorption\n(mol photons (Cmol biomass)$^{-1}$)',fontsize=20,multialignment='center')
ax.set_ylabel('Net O$_2$ Production\n(mol O$_2$ (Cmol biomass)$^{-1}$)',fontsize=20,multialignment='center')
plt.tick_params(labelsize=20)
ax.tick_params(axis='x',pad=10)
ax.tick_params(axis='y',pad=10)
plt.axis([0,120,0,10])
cbar = plt.colorbar(sc,cmap=cmap,norm=norm,boundaries=bounds,ticks=[0,2,4,6,8,10,12,14,16,18,20])
cbar.set_label('PSII/PSI Photon Absorption\n(mol photons (mol photons)$^{-1}$)',fontsize=20,rotation=270,multialignment='center')
cbar.ax.tick_params(labelsize=20)
plt.tight_layout()

fig.savefig('Figure2.png',bbox_inches='tight')


## ------------------------------------------------------------------------------------------ ##
## Figure 3a Plotting Routine
## ------------------------------------------------------------------------------------------ ##

import matplotlib.pyplot as plt
from matplotlib import colors

# Open .csv output files generated by MATLAB analysis
infile_total = open('total.csv','r') # Data for biomass-producing EFMs
infile_total_env = open('total_env.csv','r') # Data for tradeoff curve EFMs
infile_PSII_I = open('envefms_O2CO2_hvX_PSII_I.csv','r') # PSII/I photon absorption ratios for tradeoff curve EFMs

# Create variable names
tot_x = []
tot_y = []
env_tot_x = []
env_tot_y = []
Z_tot = []
Z_env = []

# Build variable lists from data stored in .csv files
while True:
    line = infile_total.readline()
    if (line == ''):
        break
    values = line.split(',')
    if float(values[1]) <= 120:
        tot_x.append(float(values[1])) # Photon absorption per biomass values for each EFM
        tot_y.append(float(values[0])) # O2/CO2 competition for each EFM
infile_total.close()

while True:
    line = infile_total_env.readline()
    if (line == ''):
        break
    values = line.split(',')
    env_tot_x.append(float(values[2])) # Photon absorption per biomass values for each EFM
    env_tot_y.append(float(values[1])) # O2/CO2 competition for each EFM
infile_total_env.close()

while True:
    line = infile_PSII_I.readline()
    if (line == ''):
        break
    values = line.split(',')
    Z_env.append(float(values[0])) # PSII/I photon absorption ratio for each EFM
infile_PSII_I.close()

# Create graphic
fig = plt.figure()
ax = fig.add_subplot(1,1,1)
# Specify colormap
cmap = plt.cm.get_cmap('hot')
bounds = [0.9973,0.9979,0.9985,0.9991,0.9997,1.0003] # Specify divisions for colorscale
norm = colors.BoundaryNorm(bounds,cmap.N)
# Plot biomass-producing EFMs
ax.scatter(tot_x,tot_y,facecolors='0.95',edgecolors='0.85',s=80,clip_on=False,zorder=1)
# Plot tradeoff curve EFMs with lines denoting the boundary
plt.plot(env_tot_x[0:7],env_tot_y[0:7],color='MidnightBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(env_tot_x[6:9],env_tot_y[6:9],color='MediumBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(env_tot_x[8:10],env_tot_y[8:10],color='RoyalBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(env_tot_x[10:86],env_tot_y[10:86],color='LightBlue',linewidth=8.0,clip_on=False,zorder=2)
sc = ax.scatter(env_tot_x,env_tot_y,c=Z_env,vmin=0.9973,vmax=1.0003,s=80,clip_on=False,zorder=3,cmap=cmap,norm=norm)
# Specify plot parameters
ax.set_xlabel('Photon Absorption\n(mol photons (Cmol biomass)$^{-1}$)',fontsize=20,multialignment='center')
ax.set_ylabel('O$_2$/CO$_2$ Competition\n(mol O$_2$ (mol CO$_2$)$^{-1}$)',fontsize=20,multialignment='center')
ax.tick_params(labelsize=20)
ax.tick_params(axis='x',pad=10)
ax.tick_params(axis='y',pad=10)
ax.yaxis.set_ticks(numpy.arange(0,1.4,0.2))
ax.axis([0,120,0,1.2])
cbar = plt.colorbar(sc,cmap=cmap,norm=norm,boundaries=bounds,ticks=[0.9973,0.9979,0.9985,0.9991,0.9997,1.0003])
cbar.set_label('PSII/PSI Photon Absorption\n(mol photons (mol photons)$^{-1}$)',fontsize=20,rotation=270,multialignment='center')
cbar.ax.tick_params(labelsize=15)
plt.tight_layout()

fig.savefig('Figure3a.png',bbox_inches='tight')


## ------------------------------------------------------------------------------------------ ##
## Figure 3b Plotting Routine
## ------------------------------------------------------------------------------------------ ##

import matplotlib.pyplot as plt
from matplotlib import colors

# Open .csv output files generated by MATLAB analysis
infile_total = open('total_O2X_hvX.csv','r') # Data for biomass-producing EFMs
infile_Fig4 = open('Fig4_O2X_hvX.csv','r') # Data for tradeoff curve EFMs from Figure 2a
infile_PSII_I = open('envefms_O2CO2_hvX_PSII_I.csv','r') # PSII/I photon absorption ratios for tradeoff curve EFMs from Figure 2a

# Create variable names
tot_x = []
tot_y = []
Fig4_x = []
Fig4_y = []
Z = []

# Build variable lists from data stored in .csv files
while True:
    line = infile_total.readline()
    if (line == ''):
        break
    values = line.split(',')
    if float(values[0]) <= 10 and float(values[1]) <= 200:
        tot_x.append(float(values[1])) # Photon absorption per biomass values for each EFM
        tot_y.append(float(values[0])) # O2 evolved per biomass values for each EFM
infile_total.close()

while True:
    line = infile_Fig4.readline()
    if (line == ''):
        break
    values = line.split(',')
    Fig4_x.append(float(values[0])) # Photon absorption per biomass values for each EFM
    Fig4_y.append(float(values[1])) # O2 evolved per biomass values for each EFM
infile_Fig4.close()

while True:
    line = infile_PSII_I.readline()
    if (line == ''):
        break
    values = line.split(',')
    Z.append(float(values[0])) # PSII/I photon absorption ratio for each EFM
infile_PSII_I.close()

# Create graphic
fig = plt.figure()
ax = fig.add_subplot(1,1,1)
# Specify colormap
cmap = plt.cm.get_cmap('hot')
bounds = [0.9973,0.9979,0.9985,0.9991,0.9997,1.0003] # Specify divisions for colorscale
norm = colors.BoundaryNorm(bounds,cmap.N)
# Plot biomass-producing EFMs
ax.scatter(tot_x,tot_y,s=80,facecolors='0.95',edgecolors='0.85')
# Plot tradeoff curve EFMs from Figure 2a with lines denoting the boundary
sc = ax.scatter(Fig4_x,Fig4_y,c=Z,vmin=0.9973,vmax=1.0003,s=80,clip_on=False,zorder=3,cmap=cmap,norm=norm)
plt.plot(Fig4_x[0:7],Fig4_y[0:7],color='MidnightBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(Fig4_x[6:9],Fig4_y[6:9],color='MediumBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(Fig4_x[8:10],Fig4_y[8:10],color='RoyalBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(Fig4_x[10:86],Fig4_y[10:86],color='LightBlue',linewidth=8.0,clip_on=False,zorder=2)
# Specify plot parameters
ax.set_xlabel('Photon Absorption\n(mol photons (Cmol biomass)$^{-1}$)',fontsize=20,multialignment='center')
ax.set_ylabel('Net O$_2$ Production\n(mol O$_2$ (Cmol biomass)$^{-1}$)',fontsize=20,multialignment='center')
plt.tick_params(labelsize=20)
ax.tick_params(axis='x',pad=10)
ax.tick_params(axis='y',pad=10)
plt.axis([0,120,0,10])
cbar = plt.colorbar(sc,cmap=cmap,norm=norm,boundaries=bounds,ticks=[0.9973,0.9979,0.9985,0.9991,0.9997,1.0003])
cbar.set_label('PSII/PSI Photon Absorption\n(mol photons (mol photons)$^{-1}$)',fontsize=20,rotation=270,multialignment='center')
cbar.ax.tick_params(labelsize=15)
plt.tight_layout()

fig.savefig('Figure3b.png',bbox_inches='tight')


## ------------------------------------------------------------------------------------------ ##
## Figure S2a Plotting Routine
## ------------------------------------------------------------------------------------------ ##

import matplotlib.pyplot as plt
from matplotlib import colors

# Open .csv output files generated by MATLAB analysis
infile_total = open('total_N_binary.csv','r') # Data for biomass-producing EFMs
infile_total_env = open('total_env_N_binary.csv','r') # Data for tradeoff curve EFMs
infile_PSII_I = open('envefms_O2CO2_Nbin_PSII_I.csv','r') # PSII/I photon absorption ratios for tradeoff curve EFMs

# Create variable names
tot_x = []
tot_y = []
env_tot_x = []
env_tot_y = []
Z = []

# Build variable lists from data stored in .csv files
while True:
    line = infile_total.readline()
    if (line == ''):
        break
    values = line.split(',')
    if float(values[1]) <= 153000:
        tot_x.append(float(values[1])) # Nitrogen atom investment for each EFM
        tot_y.append(float(values[0])) # O2/CO2 competition for each EFM
infile_total.close()

while True:
    line = infile_total_env.readline()
    if (line == ''):
        break
    values = line.split(',')
    env_tot_x.append(float(values[2])) # Nitrogen atom investment for each EFM
    env_tot_y.append(float(values[1])) # O2/CO2 competition for each EFM
infile_total_env.close()

while True:
    line = infile_PSII_I.readline()
    if (line == ''):
        break
    values = line.split(',')
    Z.append(float(values[0])) # PSII/I photon absorption ratio for each EFM
infile_PSII_I.close()

# Create graphic
fig = plt.figure()
ax = fig.add_subplot(1,1,1)
# Specify colormap
cmap = plt.cm.get_cmap('hot')
bounds = [0.9973,0.9979,0.9985,0.9991,0.9997,1.0003]
norm = colors.BoundaryNorm(bounds,cmap.N)
# Plot biomass-producing EFMs
ax.scatter(tot_x,tot_y,facecolors='0.95',edgecolors='0.85',s=80,clip_on=False,zorder=1)
# Plot tradeoff curve EFMs with lines denoting the boundary
plt.plot(env_tot_x[0:8],env_tot_y[0:8],color='MediumBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(env_tot_x[7:9],env_tot_y[7:9],color='RoyalBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(env_tot_x[8:17],env_tot_y[8:17],color='LightBlue',linewidth=8.0,clip_on=False,zorder=2)
sc = plt.scatter(env_tot_x,env_tot_y,c=Z,vmin=0.9975,vmax=1.0000,s=80,clip_on=False,zorder=3,cmap=cmap,norm=norm)
# Specify plot parameters
ax.set_xlabel('Nitrogen Investment\n(Nitrogen Atoms per EFM)',fontsize=20,multialignment='center')
ax.set_ylabel('O$_2$/CO$_2$ Competition\n(mol O$_2$ (mol CO$_2$)$^{-1}$)',fontsize=20,multialignment='center')
plt.tick_params(labelsize=16)
ax.tick_params(axis='x',pad=10)
ax.tick_params(axis='y',pad=10)
plt.axis([146000,153000,0,1.2])
plt.ticklabel_format(style='sci',axis='x',scilimits=(0,0))
ax.yaxis.set_ticks(numpy.arange(0,1.4,0.2))
cbar = plt.colorbar(sc,cmap=cmap,norm=norm,boundaries=bounds,ticks=[0.9973,0.9979,0.9985,0.9991,0.9997,1.0003])
cbar.set_label('PSII/PSI Photon Absorption\n(mol photons (mol photons)$^{-1}$)',fontsize=20,rotation=270,multialignment='center')
cbar.ax.tick_params(labelsize=15)
plt.tight_layout()

fig.savefig('FigureS2a.png',bbox_inches='tight')


## ------------------------------------------------------------------------------------------ ##
## Figure S2b Plotting Routine
## ------------------------------------------------------------------------------------------ ##

import matplotlib.pyplot as plt
from matplotlib import colors

# Open .csv output files generated by MATLAB analysis
infile_total = open('total_Fe_binary.csv','r') # Data for biomass-producing EFMs
infile_total_env = open('total_env_Fe_binary.csv','r') # Data for tradeoff curve EFMs
infile_PSII_I = open('envefms_O2CO2_Febin_PSII_I.csv','r') # PSII/I photon absorption ratios for tradeoff curve EFMs

# Create variable names
tot_x = []
tot_y = []
env_tot_x = []
env_tot_y = []
Z = []

# Build variable lists from data stored in .csv files
while True:
    line = infile_total.readline()
    if (line == ''):
        break
    values = line.split(',')
    tot_x.append(float(values[1])) # Iron atom investment for each EFM
    tot_y.append(float(values[0])) # O2/CO2 competition for each EFM
infile_total.close()

while True:
    line = infile_total_env.readline()
    if (line == ''):
        break
    values = line.split(',')
    env_tot_x.append(float(values[2])) # Iron atom investment for each EFM
    env_tot_y.append(float(values[1])) # O2/CO2 competition for each EFM
infile_total_env.close()

while True:
    line = infile_PSII_I.readline()
    if (line == ''):
        break
    values = line.split(',')
    Z.append(float(values[0])) # PSII/I photon absorption ratio for each EFM
infile_PSII_I.close()

# Create graphic
fig = plt.figure()
ax = fig.add_subplot(1,1,1)
# Specify colormap
cmap = plt.cm.get_cmap('hot_r')
bounds = [0.75,1.05,1.35,1.65,1.95,2.25]
norm = colors.BoundaryNorm(bounds,cmap.N)
# Plot biomass-producing EFMs
ax.scatter(tot_x,tot_y,facecolors='0.95',edgecolors='0.85',s=80,clip_on=False,zorder=1)
# Plot tradeoff curve EFMs with lines denoting the boundary
plt.plot(env_tot_x[0:4],env_tot_y[0:4],color='MediumBlue',linewidth=8.0,clip_on=False,zorder=2)
plt.plot(env_tot_x[1:6],env_tot_y[1:6],color='LightBlue',linewidth=8.0,clip_on=False,zorder=2)
sc = plt.scatter(env_tot_x,env_tot_y,c=Z,vmin=0.90,vmax=2.10,s=80,clip_on=False,zorder=3,cmap=cmap,norm=norm)
# Specify plot parameters
ax.set_xlabel('Iron Investment\n(Iron Atoms per EFM)',fontsize=20,multialignment='center')
ax.set_ylabel('O$_2$/CO$_2$ Competition\n(mol O$_2$ (mol CO$_2$)$^{-1}$)',fontsize=20,multialignment='center')
plt.tick_params(labelsize=20)
ax.tick_params(axis='x',pad=10)
ax.tick_params(axis='y',pad=10)
ax.yaxis.set_ticks(numpy.arange(0,1.4,0.2))
plt.axis([53,61,0,1.2])
cbar = plt.colorbar(sc,cmap=cmap,norm=norm,boundaries=bounds,ticks=[0.75,1.05,1.35,1.65,1.95,2.25])
cbar.set_label('PSII/PSI Photon Absorption\n(mol photons (mol photons)$^{-1}$)',fontsize=20,rotation=270,multialignment='center')
cbar.ax.tick_params(labelsize=15)
plt.tight_layout()

fig.savefig('FigureS2b.png',bbox_inches='tight')
